Skip to main content Module mem Copy item path Source MemError clear Clears the memory refs of the supplied pid. If no pid is supplied,
clears the memory refs of the current process. hwm Returns the high water mark of the supplied pid in bytes. If no pid
is supplied, the high water mark of the current process is returned. rss Returns the resident set size of the supplied pid in bytes. If no pid
is supplied, the resident set size of the current process is returned. size_of Returns the size of the supplied value in bytes. size_of_vec Returns the size of the supplied vector in bytes. stat Returns a parsed status member from the process status file.
If a pid is supplied, the status member of that process is returned;
otherwise, the status member of the current process is returned. total Returns the total physical memory of the system in bytes.